@@ -21,7 +21,9 @@ from google.cloud.vmmigration_v1.services.vm_migration.client import VmMigration
 from google.cloud.vmmigration_v1.types.vmmigration import (
     AddGroupMigrationRequest,
     AddGroupMigrationResponse,
+    ApplianceVersion,
     AppliedLicense,
+    AvailableUpdates,
     CancelCloneJobRequest,
     CancelCloneJobResponse,
     CancelCutoverJobRequest,
@@ -79,6 +81,7 @@ from google.cloud.vmmigration_v1.types.vmmigration import (
     ListUtilizationReportsRequest,
     ListUtilizationReportsResponse,
     MigratingVm,
+    MigratingVmView,
     MigrationError,
     NetworkInterface,
     OperationMetadata,
@@ -100,6 +103,9 @@ from google.cloud.vmmigration_v1.types.vmmigration import (
     UpdateMigratingVmRequest,
     UpdateSourceRequest,
     UpdateTargetProjectRequest,
+    UpgradeApplianceRequest,
+    UpgradeApplianceResponse,
+    UpgradeStatus,
     UtilizationReport,
     UtilizationReportView,
     VmUtilizationInfo,
@@ -114,7 +120,9 @@ __all__ = (
     "VmMigrationAsyncClient",
     "AddGroupMigrationRequest",
     "AddGroupMigrationResponse",
+    "ApplianceVersion",
     "AppliedLicense",
+    "AvailableUpdates",
     "CancelCloneJobRequest",
     "CancelCloneJobResponse",
     "CancelCutoverJobRequest",
@@ -190,6 +198,9 @@ __all__ = (
     "UpdateMigratingVmRequest",
     "UpdateSourceRequest",
     "UpdateTargetProjectRequest",
+    "UpgradeApplianceRequest",
+    "UpgradeApplianceResponse",
+    "UpgradeStatus",
     "UtilizationReport",
     "VmUtilizationInfo",
     "VmUtilizationMetrics",
@@ -199,5 +210,6 @@ __all__ = (
     "ComputeEngineBootOption",
     "ComputeEngineDiskType",
     "ComputeEngineLicenseType",
+    "MigratingVmView",
     "UtilizationReportView",
 )
