@@ -16,7 +16,9 @@
 from .vmmigration import (
     AddGroupMigrationRequest,
     AddGroupMigrationResponse,
+    ApplianceVersion,
     AppliedLicense,
+    AvailableUpdates,
     CancelCloneJobRequest,
     CancelCloneJobResponse,
     CancelCutoverJobRequest,
@@ -74,6 +76,7 @@ from .vmmigration import (
     ListUtilizationReportsRequest,
     ListUtilizationReportsResponse,
     MigratingVm,
+    MigratingVmView,
     MigrationError,
     NetworkInterface,
     OperationMetadata,
@@ -95,6 +98,9 @@ from .vmmigration import (
     UpdateMigratingVmRequest,
     UpdateSourceRequest,
     UpdateTargetProjectRequest,
+    UpgradeApplianceRequest,
+    UpgradeApplianceResponse,
+    UpgradeStatus,
     UtilizationReport,
     UtilizationReportView,
     VmUtilizationInfo,
@@ -107,7 +113,9 @@ from .vmmigration import (
 __all__ = (
     "AddGroupMigrationRequest",
     "AddGroupMigrationResponse",
+    "ApplianceVersion",
     "AppliedLicense",
+    "AvailableUpdates",
     "CancelCloneJobRequest",
     "CancelCloneJobResponse",
     "CancelCutoverJobRequest",
@@ -183,6 +191,9 @@ __all__ = (
     "UpdateMigratingVmRequest",
     "UpdateSourceRequest",
     "UpdateTargetProjectRequest",
+    "UpgradeApplianceRequest",
+    "UpgradeApplianceResponse",
+    "UpgradeStatus",
     "UtilizationReport",
     "VmUtilizationInfo",
     "VmUtilizationMetrics",
@@ -192,5 +203,6 @@ __all__ = (
     "ComputeEngineBootOption",
     "ComputeEngineDiskType",
     "ComputeEngineLicenseType",
+    "MigratingVmView",
     "UtilizationReportView",
 )
